# [Changelog](https://github.com/hgibs/cinefiles/releases)

##v0.1.3 (alpha)
- added working (if useless) tests

##v0.1.2 (alpha)
- fixed a lot of packaging issues

##v0.1.1 (alpha)
- created the project
